---
title: PDF Export
page_title: PDF Export - PivotGrid - Kendo UI for Vue
description: "Explore the PDF export options provided by the Kendo UI PivotGrid wrapper for Vue."
slug: pdf_export_pivotgrid
position: 4
---

# PDF Export

The built-in export functionality of the PivotGrid allows you to easily export data to PDF.

## Basics

The Kendo PivotGrid Vue component provides client PDF export functionality (server-agnostic) which is powered by the underlying Drawing API engine of the Kendo UI framework. To enable it, configure the PDF export settings. You can trigger PDF export by invoking the [saveAsPDF](https://docs.telerik.com/kendo-ui/api/javascript/ui/pivotgrid/methods/saveaspdf) method from the client API of the PivotGrid.

{% meta height:490 %}
```html-preview
<div id="vueapp" class="vue-app">
    <kendo-button @click="onClick" class="k-primary">Export</kendo-button>
    <kendo-pivotdatasource ref="pivotdatasource1"
                           transport-read-url="https://demos.telerik.com/olap/msmdpump.dll"
                           transport-connection-catalog="Adventure Works DW 2008R2"
                           transport-connection-cube="Adventure Works"
                           type="xmla"
                           schema-type="xmla"
                           :measures="measures">
          <kendo-pivot-column :name="'[Date].[Calendar]'" :expand="true"></kendo-pivot-column>
          <kendo-pivot-row :name="'[Product].[Product Line]'" :expand="true"></kendo-pivot-row>
    </kendo-pivotdatasource>
    <kendo-pivotgrid id="pivotgrid1"
                     ref="pivot1"
                     data-source-ref="pivotdatasource1"
                     :columnWidth="200"
                     :height="400"
                     :pdf-proxy-URL="'https://demos.telerik.com/kendo-ui/service/export'"
                     :pdf-file-name="'Kendo UI PivotGrid Export.pdf'">
    </kendo-pivotgrid>
</div>
<style>
    .hidden-on-narrow {
        display: inline-block;
        vertical-align: top;
    }
</style>
```
```js
Vue.use(ButtonsInstaller);
Vue.use(PivotGridInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: '#vueapp',
    data () {
        return {
            measures: ['[Measures].[Reseller Freight Cost]']
        }
    },
    methods: {
      onClick: function (ev) {
        var pivot = this.$refs.pivot1.kendoWidget()
        pivot.saveAsPDF()
      }
    }
})
```
{% endmeta %}

## Suggested Links

* [Kendo UI PivotGrid for jQuery](https://docs.telerik.com/kendo-ui/controls/data-management/pivotgrid/overview)
* [API Reference of the PivotGrid Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/pivotgrid)
