---
title: Templates
page_title: Templates - PivotGrid - Kendo UI for Vue
description: "Templates functionality of the Kendo UI PivotGrid wrapper for Vue."
slug: templates_pivotgrid
position: 2
---

# PivotGrid Templates

The PivotGrid Vue component allows flexible customization of its appearance by exposing templates for this purpose

The PivotGrid provides several templates for customization:
* [Data Cell Template](#toc-data-cell-template), or
* [Column Header Template](#toc-column-header-template), or
* [Row Header Template](#toc-row-header-template).

## Data Cell Template

You can set the Data Cell Template of the PivotGrid through the `:data-cell-template` prop.

{% meta height:460 %}
```html-preview
<div id="vueapp" class="vue-app">
    <kendo-pivotdatasource ref="pivotdatasource1"
                           transport-read-url="https://demos.telerik.com/olap/msmdpump.dll"
                           transport-connection-catalog="Adventure Works DW 2008R2"
                           transport-connection-cube="Adventure Works"
                           type="xmla"
                           schema-type="xmla"
                           :measures="measures">
          <kendo-pivot-column :name="'[Date].[Calendar]'" :expand="true"></kendo-pivot-column>
          <kendo-pivot-row :name="'[Product].[Product Line]'" :expand="true"></kendo-pivot-row>
    </kendo-pivotdatasource>
    <kendo-pivotgrid id="pivotgrid1"
                     data-source-ref="pivotdatasource1"
                     :data-cell-template="dataCellTemplate"
                     :columnWidth="200"
                     :height="400" >
    </kendo-pivotgrid>
</div>
<style>
    .hidden-on-narrow {
        display: inline-block;
        vertical-align: top;
    }
</style>
```
```js
Vue.use(PivotGridInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: '#vueapp',
    data () {
        return {
            dataCellTemplate: this.generateDataCellTemplate(),
            measures: ['[Measures].[Reseller Freight Cost]']
        }
    },
    methods: {
        generateDataCellTemplate: function() {
            var template =
            '# var columnMember = columnTuple ? columnTuple.members[0] : { children: [] }; #' +
            '# var rowMember = rowTuple ? rowTuple.members[0] : { children: [] }; #' +
            '# var value = kendo.toString(kendo.parseFloat(dataItem.value) || "N/A", "c2"); #' +
            '# if (columnMember.children.length || rowMember.children.length) { #' +
                '#: value #' +
            '# } else { #' +
                '<em  style="color: red">#: value # (total)</em>' +
            '# } #'

            return kendo.template(template)
        }
    }
})
```
{% endmeta %}

## Column Header Template

You can set the Column Header Template of the PivotGrid through the `:column-header-template` prop.

```html
<div id="vueapp" class="vue-app">
    <kendo-pivotdatasource ref="pivotdatasource1"
                           transport-read-url="https://demos.telerik.com/olap/msmdpump.dll"
                           transport-connection-catalog="Adventure Works DW 2008R2"
                           transport-connection-cube="Adventure Works"
                           type="xmla"
                           schema-type="xmla"
                           :measures="measures">
          <kendo-pivot-column :name="'[Date].[Calendar]'" :expand="true"></kendo-pivot-column>
          <kendo-pivot-row :name="'[Product].[Product Line]'" :expand="true"></kendo-pivot-row>
    </kendo-pivotdatasource>
    <kendo-pivotgrid id="pivotgrid1"
                     data-source-ref="pivotdatasource1"
                     :column-header-template="columnHeaderTemplate"
                     :columnWidth="200"
                     :height="400" >
    </kendo-pivotgrid>
</div>
<style>
    .hidden-on-narrow {
        display: inline-block;
        vertical-align: top;
    }
</style>
```
```js
Vue.use(PivotGridInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: '#vueapp',
    data () {
        return {
            columnHeaderTemplate: this.generateColumnHeaderTemplate(),
            measures: ['[Measures].[Reseller Freight Cost]']
        }
    },
    methods: {
        generateColumnHeaderTemplate: function() {
            var template =
            '# if (!member.children.length) { #' +
                '<em>#: member.caption #</em>' +
            '# } else { #' +
                '#: member.caption #' +
            '# } #'

            return kendo.template(template)
        }
    }
})
```

## Row Header Template

You can set the Row Header Template of the PivotGrid through the `:row-header-template` prop.

```html
<div id="vueapp" class="vue-app">
    <kendo-pivotdatasource ref="pivotdatasource1"
                           transport-read-url="https://demos.telerik.com/olap/msmdpump.dll"
                           transport-connection-catalog="Adventure Works DW 2008R2"
                           transport-connection-cube="Adventure Works"
                           type="xmla"
                           schema-type="xmla"
                           :measures="measures">
          <kendo-pivot-column :name="'[Date].[Calendar]'" :expand="true"></kendo-pivot-column>
          <kendo-pivot-row :name="'[Product].[Product Line]'" :expand="true"></kendo-pivot-row>
    </kendo-pivotdatasource>
    <kendo-pivotgrid id="pivotgrid1"
                     data-source-ref="pivotdatasource1"
                     :row-header-template="rowHeaderTemplate"
                     :columnWidth="200"
                     :height="400" >
    </kendo-pivotgrid>
</div>
<style>
    .hidden-on-narrow {
        display: inline-block;
        vertical-align: top;
    }
</style>
```
```js
Vue.use(PivotGridInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: '#vueapp',
    data () {
        return {
            rowHeaderTemplate: this.generateRowHeaderTemplate(),
            measures: ['[Measures].[Reseller Freight Cost]']
        }
    },
    methods: {
        generateRowHeaderTemplate: function() {
            var template =
            '# if (!member.children.length) { #' +
                '<em>#: member.caption #</em>' +
            '# } else { #' +
                '#: member.caption #' +
            '# } #'

            return kendo.template(template)
        }
    }
})
```

## Suggested Links

* [Kendo UI PivotGrid for jQuery](https://docs.telerik.com/kendo-ui/controls/data-management/pivotgrid/overview)
* [API Reference of the PivotGrid Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/pivotgrid)
